@@ -24,7 +24,6 @@
 #include <em-format/e-mail-part-utils.h>
 #include <e-util/e-util.h>
 
-#include <shell/e-shell-settings.h>
 #include <shell/e-shell.h>
 
 #include <libebackend/libebackend.h>
@@ -36,6 +35,7 @@
 
 #include "misc.h"
 #include "rss-formatter.h"
+#include "e-mail-part-rss.h"
 
 
 typedef EMailFormatterExtension EMailFormatterRSS;
@@ -91,40 +91,56 @@ emfe_evolution_rss_format (EMailFormatterExtension *extension,
 				EMailFormatter *formatter,
 				EMailFormatterContext *context,
 				EMailPart *part,
+#if EVOLUTION_VERSION < 31191
 				CamelStream *stream,
+#else
+				GOutputStream *stream,
+#endif
 				GCancellable *cancellable)
 {
-	CamelStream *decoded_stream;
 	CamelDataWrapper *dw;
 	gchar *str;
+#if EVOLUTION_VERSION < 31191
+	CamelStream *decoded_stream;
 	GByteArray *ba;
+#else
+	GOutputStream *decoded_stream;
+	gpointer data;
+	gsize len;
+#endif
 	gchar *src;
-	CamelMimePart *message = (CamelMimePart *)part->part;
+	CamelMimePart *message = e_mail_part_ref_mime_part (part);
 	gchar *website, *subject, *category, *feedid, *comments;
 	guint32 frame_col, cont_col, text_col;
 	gboolean is_html = NULL;
 	gchar *feed_dir, *tmp_file, *tmp_path, *iconfile;
 	GdkPixbuf *pixbuf;
 
-	CamelContentType *ct = camel_mime_part_get_content_type (part->part);
+
+	CamelContentType *ct = camel_mime_part_get_content_type (message);
 	if (ct) {
 		if (!camel_content_type_is (ct, "x-evolution", "evolution-rss-feed"))
-			return FALSE;
+			goto fail;
 	}
 
-	dw = camel_medium_get_content (CAMEL_MEDIUM (part->part));
+	dw = camel_medium_get_content (CAMEL_MEDIUM (message));
 	if (!dw) {
-		return FALSE;
+		goto fail;
 	}
 
 	str = g_strdup_printf (
 		"<object type=\"application/vnd.evolution.attachment\" "
 		"height=\"0\" width=\"100%%\" data=\"%s\" id=\"%s\"></object>",
-		part->id, part->id);
+		e_mail_part_get_id(part),
+		e_mail_part_get_id(part));
+#if EVOLUTION_VERSION < 31191
 	camel_stream_write_string (
 		stream, str, cancellable, NULL);
+#else
+	g_output_stream_write_all(stream, str,
+		strlen(str), NULL, cancellable, NULL);
+#endif
 	gchar *h = g_strdup(e_web_view_get_html (E_WEB_VIEW (rss_get_display())));
-	g_print("h:%s\n\n\n\n", h);
 
 	website = camel_medium_get_header (
 			CAMEL_MEDIUM (message), "Website");
@@ -166,11 +182,11 @@ emfe_evolution_rss_format (EMailFormatterExtension *extension,
 		}
 	}
 
-	frame_col = e_color_to_value ((GdkColor *)
+	frame_col = e_rgba_to_value (
 			e_mail_formatter_get_color (formatter, E_MAIL_FORMATTER_COLOR_FRAME));
-	cont_col = e_color_to_value ((GdkColor *)
+	cont_col = e_rgba_to_value (
 			e_mail_formatter_get_color (formatter, E_MAIL_FORMATTER_COLOR_CONTENT));
-	text_col = e_color_to_value ((GdkColor *)
+	text_col = e_rgba_to_value (
 			e_mail_formatter_get_color (formatter, E_MAIL_FORMATTER_COLOR_TEXT));
 
 	if (!is_html && !rss_get_current_view()) {
@@ -188,25 +204,53 @@ emfe_evolution_rss_format (EMailFormatterExtension *extension,
 			text_col & 0xffffff,
 			iconfile, website, subject);
 
+#if EVOLUTION_VERSION < 31191
 		camel_stream_write_string (
 			stream, str, cancellable, NULL);
+#else
+		g_output_stream_write_all(stream, str,
+			strlen(str), NULL, cancellable, NULL);
+#endif
 
+#if EVOLUTION_VERSION < 31191
 		decoded_stream = camel_stream_mem_new ();
+#else
+		decoded_stream = g_memory_output_stream_new_resizable ();
+#endif
 
 		e_mail_formatter_format_text (
 			formatter, part, decoded_stream, cancellable);
 
+#if EVOLUTION_VERSION < 31191
 		g_seekable_seek (G_SEEKABLE (decoded_stream), 0, G_SEEK_SET, cancellable, NULL);
 
 		ba = camel_stream_mem_get_byte_array (CAMEL_STREAM_MEM (decoded_stream));
 		src = rss_process_feed((gchar *)ba->data, ba->len);
+#else
+		data = g_memory_output_stream_get_data (
+				G_MEMORY_OUTPUT_STREAM (decoded_stream));
+		len = g_memory_output_stream_get_data_size (
+				G_MEMORY_OUTPUT_STREAM (decoded_stream));
+		src = rss_process_feed((gchar *)data, len);
+#endif
 
+#if EVOLUTION_VERSION < 31191
 		camel_stream_write_string(stream, src, cancellable, NULL);
+#else
+		g_output_stream_write_all(stream, src, strlen(src), NULL, cancellable, NULL);
+#endif
 		g_free(src);
 		g_object_unref (decoded_stream);
 
+#if EVOLUTION_VERSION < 31191
 		camel_stream_write_string (
 			stream, "</div></div>", cancellable, NULL);
+#else
+		gchar *tstr = g_strdup("</div></div>");
+		g_output_stream_write_all(stream, tstr,
+				strlen(tstr), NULL, cancellable, NULL);
+		g_free(tstr);
+#endif
 	} else {
 		GError *err = NULL;
 		gchar *str;
@@ -225,13 +269,28 @@ emfe_evolution_rss_format (EMailFormatterExtension *extension,
 				frame_col & 0xffffff,
 				cont_col & 0xffffff,
 				text_col & 0xffffff);
+#if EVOLUTION_VERSION < 31191
 			camel_stream_write_string (stream, str, cancellable, NULL);
-			g_free (str);
 			camel_stream_write_string (stream, "<div style=\"border: solid 0px; padding: 4px;\">\n", cancellable, NULL);
 			camel_stream_write_string (stream, "<h3>Error!</h3>", cancellable, NULL);
 			camel_stream_write_string (stream, err->message, cancellable, NULL);
 			camel_stream_write_string (stream, "</div>", cancellable, NULL);
-			return TRUE;
+#else
+			g_output_stream_write_all(stream, str, strlen(str), NULL, cancellable, NULL);
+			gchar *tstr;
+			tstr = g_strdup("<div style=\"border: solid 0px; padding: 4px;\">\n");
+			g_output_stream_write_all(stream, tstr, strlen(tstr), NULL, cancellable, NULL);
+			g_free(tstr);
+			tstr = g_strdup("<h3>Error!</h3>");
+			g_output_stream_write_all(stream, tstr, strlen(tstr), NULL, cancellable, NULL);
+			g_free(tstr);
+			g_output_stream_write_all(stream, err->message, strlen(err->message), NULL, cancellable, NULL);
+			tstr = g_strdup("</div>");
+			g_output_stream_write_all(stream, tstr, strlen(tstr), NULL, cancellable, NULL);
+			g_free(tstr);
+#endif
+			g_free (str);
+			goto success;
 		}
 
 		gchar *buff = rss_process_website(content->str, website);
@@ -274,7 +333,11 @@ emfe_evolution_rss_format (EMailFormatterExtension *extension,
 	g_idle_add((GSourceFunc)feed_async, hd);
 	}
 
+success:g_object_unref(message);
 	return TRUE;
+fail:
+	g_object_unref(message);
+	return FALSE;
 }
 
 static void
