@@ -1,5 +1,5 @@
 /*  Evoution RSS Reader Plugin
- *  Copyright (C) 2007-2010 Lucian Langa <cooly@gnome.eu.org>
+ *  Copyright (C) 2007-2015 Lucian Langa <cooly@gnome.eu.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,11 +25,16 @@
 #include <libxml/HTMLparser.h>
 #include <libxml/HTMLtree.h>
 #include <libxml/debugXML.h>
+
+#if EVOLUTION_VERSION >= 31102
+#include <libemail-engine/libemail-engine.h>
+#else
 #if EVOLUTION_VERSION >= 30305
 #include <libemail-engine/mail-ops.h>
 #else
 #include <mail/mail-ops.h>
 #endif
+#endif
 #if EVOLUTION_VERSION >= 30505
 #include <mail/e-mail-reader-utils.h>
 #endif
@@ -64,7 +69,11 @@ extern int rss_verbose_debug;
 #include "misc.h"
 #include "network-soup.h"
 
-//extern GConfClient *rss_gconf;
+#if EVOLUTION_VERSION < 30304
+extern GConfClient *rss_gconf;
+#else
+static GSettings *rss_settings;
+#endif
 void asyncr_context_free(AsyncData *asyncr);
 GQueue *display_channel_items_sync(AsyncData *ayncr);
 
@@ -84,6 +93,7 @@ rss_html_url_decode(const char *html, int len)
 	xmlDoc *doc = NULL;
 	gchar *url;
 	gchar *duri = NULL;
+	gboolean any_changed = FALSE;
 
 	src = (xmlDoc *)parse_html_sux(html, len);
 
@@ -101,6 +111,7 @@ rss_html_url_decode(const char *html, int len)
 #else
 				duri = g_strconcat("evo-file://", tmp, NULL);
 #endif
+				any_changed = TRUE;
 				g_free(tmp);
 				xmlSetProp(
 					(xmlNodePtr)doc,
@@ -110,6 +121,12 @@ rss_html_url_decode(const char *html, int len)
 			xmlFree(url);
 		}
 	}
+
+	if (!any_changed) {
+		xmlFreeDoc(src);
+		src = NULL;
+	}
+
 	return src;
 }
 
@@ -320,6 +337,7 @@ parse_html(char *url, const char *html, int len)
 		return NULL;
 	doc = src;
 	newbase = (gchar *)xmlGetProp(html_find((xmlNode *)doc, (gchar *)"base"), (xmlChar *)"href");
+
 	d("newbase:|%s|\n", newbase);
 	tmpdoc = (xmlDoc *)html_find((xmlNode *)doc, (gchar *)"base");
 	xmlUnlinkNode((xmlNode *)tmpdoc);
@@ -327,6 +345,7 @@ parse_html(char *url, const char *html, int len)
 	html_set_base((xmlNode *)doc, url, "img", "src", newbase);
 	html_set_base((xmlNode *)doc, url, "input", "src", newbase);
 	html_set_base((xmlNode *)doc, url, "link", "src", newbase);
+	html_set_base((xmlNode *)doc, url, "link", "href", newbase);
 	html_set_base((xmlNode *)doc, url, "body", "background", newbase);
 	html_set_base((xmlNode *)doc, url, "script", "src", newbase);
 /*      while (doc = html_find((xmlNode *)doc, "img"))
@@ -1061,7 +1080,8 @@ parse_channel_line(xmlNode *top, gchar *feed_name, RDF *r, gchar **article_uid)
 	gchar *qsafe, *tcat;
 	GList *category = NULL;
 	create_feed *CF;
-	GList *attachments = NULL;
+	GList *attachments = NULL, *attsizes = NULL, *l = NULL;
+	GHashTable *attlengths = NULL;
 	gchar *base = NULL, *main_date = NULL;
 
 	if (r) {
@@ -1201,10 +1221,20 @@ parse_channel_line(xmlNode *top, gchar *feed_name, RDF *r, gchar **article_uid)
 		}
 		//handle attatchments (can be multiple)
 		attachments = layer_find_tag_prop(top, "media", "url");
-		if (!attachments)
+		attsizes = layer_find_tag_prop(top, "media", "fileSize");
+		if (!attachments) {
 			attachments = layer_query_find_all_prop (top,
 				"link", (xmlChar *)"rel",
 				"enclosure", (xmlChar *)"href");
+			attsizes = layer_query_find_all_prop (top,
+				"link", (xmlChar *)"rel",
+				"enclosure", (xmlChar *)"length");
+		}
+		attlengths = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
+		for (l = g_list_first(attsizes); l != NULL; l = l->next) {
+			gchar *c = get_url_basename(g_list_first(attachments)->data);
+			g_hash_table_insert(attlengths, g_strdup(c), g_strdup(l->data));
+		}
 
 //                char *comments = g_strdup(layer_find (top, "comments", NULL));	//RSS,
 		comments = (gchar *)layer_find_ns_tag(top, "wfw", "commentRss", NULL); //add slash:comments
@@ -1243,6 +1273,7 @@ parse_channel_line(xmlNode *top, gchar *feed_name, RDF *r, gchar **article_uid)
 		CF->website	= g_strdup(link);
 		CF->encl	= g_strdup(encl);
 		CF->attachments	= attachments;
+		CF->attlengths	= attlengths;
 		CF->comments	= g_strdup(comments);
 		CF->feed_fname  = g_strdup(feed_name);	//feed file name
 		CF->feed_uri	= g_strdup(feed);	//feed uri (uid!)
@@ -1339,17 +1370,24 @@ display_channel_items_sync(AsyncData *asyncr)
 		subj = g_strdup(CF->subj);
 
 		ftotal++;
-#if 0
+#if EVOLUTION_VERSION < 30304
+		GConfClient *client = gconf_client_get_default();
+#else
+		rss_settings = g_settings_new(RSS_CONF_SCHEMA);
+#endif
+#if EVOLUTION_VERSION < 30304
 		if (gconf_client_get_bool(rss_gconf, GCONF_KEY_DOWNLOAD_ENCLOSURES, NULL)) {
+#else
+		if (g_settings_get_boolean(rss_settings, CONF_DOWNLOAD_ENCLOSURES)) {
+#endif
 			if (CF->encl) {
-				process_enclosure(CF);
-				goto done;
+				if (process_enclosure(CF))
+					goto done;
 			} else if (g_list_length(CF->attachments)) {
-				process_attachments(CF);
-				goto done;
+				if (process_attachments(CF))
+					goto done;
 			}
 		}
-#endif
 
 		if (!freeze) {
 			camel_folder_freeze(mail_folder);
